@@ -8,7 +8,6 @@
 
 #include "fwupd-bios-setting.h"
 #include "fwupd-codec.h"
-#include "fwupd-common-private.h"
 #include "fwupd-enums-private.h"
 #include "fwupd-error.h"
 
@@ -626,22 +625,22 @@ fwupd_bios_setting_validate_value(FwupdBiosSetting *self, const gchar *value, GE
 		if (!_fu_strtoull_simple(value, &tmp, error))
 			return FALSE;
 		if (tmp < priv->lower_bound) {
-			g_set_error(error,
+			g_set_error(error, /* nocheck:error */
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
 				    "%s is too small (%" G_GUINT64_FORMAT
-				    "); expected at least %" G_GUINT64_FORMAT,
+				    ") expected at least %" G_GUINT64_FORMAT,
 				    value,
 				    tmp,
 				    priv->lower_bound);
 			return FALSE;
 		}
 		if (tmp > priv->upper_bound) {
-			g_set_error(error,
+			g_set_error(error, /* nocheck:error */
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
 				    "%s is too big (%" G_GUINT64_FORMAT
-				    "); expected no more than %" G_GUINT64_FORMAT,
+				    ") expected no more than %" G_GUINT64_FORMAT,
 				    value,
 				    tmp,
 				    priv->upper_bound);
@@ -652,22 +651,22 @@ fwupd_bios_setting_validate_value(FwupdBiosSetting *self, const gchar *value, GE
 	if (priv->kind == FWUPD_BIOS_SETTING_KIND_STRING) {
 		gsize tmp = strlen(value);
 		if (tmp < priv->lower_bound) {
-			g_set_error(error,
+			g_set_error(error, /* nocheck:error */
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
 				    "%s is too short (%" G_GSIZE_FORMAT
-				    "); expected at least %" G_GUINT64_FORMAT,
+				    ") expected at least %" G_GUINT64_FORMAT,
 				    value,
 				    tmp,
 				    priv->lower_bound);
 			return FALSE;
 		}
 		if (tmp > priv->upper_bound) {
-			g_set_error(error,
+			g_set_error(error, /* nocheck:error */
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
 				    "%s is too long (%" G_GSIZE_FORMAT
-				    "); expected no more than %" G_GUINT64_FORMAT,
+				    ") expected no more than %" G_GUINT64_FORMAT,
 				    value,
 				    tmp,
 				    priv->upper_bound);
@@ -803,7 +802,8 @@ fwupd_bios_setting_add_variant(FwupdCodec *codec, GVariantBuilder *builder, Fwup
 			      "{sv}",
 			      FWUPD_RESULT_KEY_BIOS_SETTING_READ_ONLY,
 			      g_variant_new_boolean(priv->read_only));
-	if (fwupd_bios_setting_trusted(self, flags & FWUPD_CODEC_FLAG_TRUSTED)) {
+	if (priv->current_value != NULL &&
+	    fwupd_bios_setting_trusted(self, flags & FWUPD_CODEC_FLAG_TRUSTED)) {
 		g_variant_builder_add(builder,
 				      "{sv}",
 				      FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE,
