@@ -11,7 +11,6 @@
 #include "fwupd-build.h"
 #include "fwupd-device.h"
 #include "fwupd-enums.h"
-#include "fwupd-plugin.h"
 #include "fwupd-remote.h"
 #include "fwupd-request.h"
 
@@ -153,6 +152,16 @@ fwupd_client_get_releases_finish(FwupdClient *self,
 				 GAsyncResult *res,
 				 GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 void
+fwupd_client_search_async(FwupdClient *self,
+			  const gchar *token,
+			  GCancellable *cancellable,
+			  GAsyncReadyCallback callback,
+			  gpointer callback_data) G_GNUC_NON_NULL(1, 2);
+GPtrArray *
+fwupd_client_search_finish(FwupdClient *self,
+			   GAsyncResult *res,
+			   GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
+void
 fwupd_client_get_downgrades_async(FwupdClient *self,
 				  const gchar *device_id,
 				  GCancellable *cancellable,
