@@ -10,7 +10,6 @@
 
 #include "fu-context.h"
 #include "fu-device-event.h"
-#include "fu-device-locker.h"
 #include "fu-device-struct.h"
 #include "fu-firmware.h"
 #include "fu-progress.h"
@@ -90,7 +89,6 @@ struct _FuDeviceClass {
 	void (*set_progress)(FuDevice *self, FuProgress *progress);
 	void (*invalidate)(FuDevice *self);
 	gchar *(*convert_version)(FuDevice *self, guint64 version_raw);
-	void (*register_flags)(FuDevice *self);
 	void (*add_json)(FuDevice *self, JsonBuilder *builder, FwupdCodecFlags flags);
 	gboolean (*from_json)(FuDevice *self,
 			      JsonObject *json_object,
@@ -839,6 +837,22 @@ fu_device_new(FuContext *ctx);
  * Since: 2.0.7
  */
 #define FU_DEVICE_PRIVATE_FLAG_INSTALL_LOOP_RESTART "install-loop-restart"
+/**
+ * FU_DEVICE_PRIVATE_FLAG_MD_SET_REQUIRED_FREE:
+ *
+ * Set the device required free size from the metadata if available.
+ *
+ * Since: 2.0.12
+ */
+#define FU_DEVICE_PRIVATE_FLAG_MD_SET_REQUIRED_FREE "md-set-required-free"
+/**
+ * FU_DEVICE_PRIVATE_FLAG_PARENT_NAME_PREFIX:
+ *
+ * Use the parent device as the name prefix.
+ *
+ * Since: 2.0.15
+ */
+#define FU_DEVICE_PRIVATE_FLAG_PARENT_NAME_PREFIX "parent-name-prefix"
 
 /* standard icons */
 
@@ -1094,7 +1108,6 @@ fu_device_new(FuContext *ctx);
  */
 #define FU_DEVICE_ICON_APPLICATION_CERTIFICATE "application-certificate"
 
-
 /* accessors */
 gchar *
 fu_device_to_string(FuDevice *self) G_GNUC_NON_NULL(1);
@@ -1109,11 +1122,12 @@ fu_device_has_guid(FuDevice *self, const gchar *guid) G_GNUC_NON_NULL(1);
 void
 fu_device_add_instance_id(FuDevice *self, const gchar *instance_id) G_GNUC_NON_NULL(1, 2);
 gboolean
-fu_device_has_instance_id(FuDevice *self, const gchar *instance_id, FuDeviceInstanceFlag flags)
+fu_device_has_instance_id(FuDevice *self, const gchar *instance_id, FuDeviceInstanceFlags flags)
     G_GNUC_NON_NULL(1, 2);
 void
-fu_device_add_instance_id_full(FuDevice *self, const gchar *instance_id, FuDeviceInstanceFlag flags)
-    G_GNUC_NON_NULL(1, 2);
+fu_device_add_instance_id_full(FuDevice *self,
+			       const gchar *instance_id,
+			       FuDeviceInstanceFlags flags) G_GNUC_NON_NULL(1, 2);
 FuDevice *
 fu_device_get_root(FuDevice *self) G_GNUC_NON_NULL(1);
 FuDevice *
@@ -1229,6 +1243,10 @@ guint64
 fu_device_get_firmware_size_min(FuDevice *self) G_GNUC_NON_NULL(1);
 guint64
 fu_device_get_firmware_size_max(FuDevice *self) G_GNUC_NON_NULL(1);
+guint64
+fu_device_get_required_free(FuDevice *self) G_GNUC_NON_NULL(1);
+void
+fu_device_set_required_free(FuDevice *self, guint64 required_free) G_GNUC_NON_NULL(1);
 guint
 fu_device_get_battery_level(FuDevice *self) G_GNUC_NON_NULL(1);
 void
@@ -1295,6 +1313,7 @@ fu_device_prepare_firmware(FuDevice *self,
 FuFirmware *
 fu_device_read_firmware(FuDevice *self,
 			FuProgress *progress,
+			FuFirmwareParseFlags flags,
 			GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 GBytes *
 fu_device_dump_firmware(FuDevice *self,
@@ -1407,9 +1426,16 @@ fu_device_set_contents_bytes(FuDevice *self,
 			     GBytes *blob,
 			     FuProgress *progress,
 			     GError **error) G_GNUC_NON_NULL(1, 2, 3);
+gchar *
+fu_device_get_contents(FuDevice *self,
+		       const gchar *filename,
+		       gsize count,
+		       FuProgress *progress,
+		       GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 GBytes *
 fu_device_get_contents_bytes(FuDevice *self,
 			     const gchar *filename,
+			     gsize count,
 			     FuProgress *progress,
 			     GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 gboolean
@@ -1444,11 +1470,16 @@ fu_device_add_instance_u16(FuDevice *self, const gchar *key, guint16 value) G_GN
 void
 fu_device_add_instance_u32(FuDevice *self, const gchar *key, guint32 value) G_GNUC_NON_NULL(1, 2);
 gboolean
+fu_device_build_instance_id_strv(FuDevice *self,
+				 const gchar *subsystem,
+				 gchar **keys,
+				 GError **error) G_GNUC_NON_NULL(1, 2);
+gboolean
 fu_device_build_instance_id(FuDevice *self, GError **error, const gchar *subsystem, ...)
     G_GNUC_NULL_TERMINATED G_GNUC_NON_NULL(1, 3);
 gboolean
 fu_device_build_instance_id_full(FuDevice *self,
-				 FuDeviceInstanceFlag flags,
+				 FuDeviceInstanceFlags flags,
 				 GError **error,
 				 const gchar *subsystem,
 				 ...) G_GNUC_NULL_TERMINATED G_GNUC_NON_NULL(1, 4);
@@ -1456,10 +1487,12 @@ void
 fu_device_build_vendor_id(FuDevice *self, const gchar *prefix, const gchar *value);
 void
 fu_device_build_vendor_id_u16(FuDevice *self, const gchar *prefix, guint16 value);
-FuDeviceLocker *
-fu_device_poll_locker_new(FuDevice *self, GError **error) G_GNUC_NON_NULL(1);
 
 FuDeviceEvent *
 fu_device_save_event(FuDevice *self, const gchar *id);
 FuDeviceEvent *
 fu_device_load_event(FuDevice *self, const gchar *id, GError **error);
+void
+fu_device_add_event(FuDevice *self, FuDeviceEvent *event);
+GPtrArray *
+fu_device_get_events(FuDevice *self);
