@@ -9,7 +9,6 @@
 #include "config.h"
 
 #include "fu-byte-array.h"
-#include "fu-bytes.h"
 #include "fu-common.h"
 #include "fu-efi-common.h"
 #include "fu-efi-lz77-decompressor.h"
@@ -18,7 +17,6 @@
 #include "fu-efi-volume.h"
 #include "fu-input-stream.h"
 #include "fu-lzma-common.h"
-#include "fu-mem.h"
 #include "fu-partial-input-stream.h"
 #include "fu-string.h"
 
@@ -60,14 +58,14 @@ fu_efi_section_export(FuFirmware *firmware, FuFirmwareExportFlags flags, XbBuild
 static gboolean
 fu_efi_section_parse_volume_image(FuEfiSection *self,
 				  GInputStream *stream,
-				  FwupdInstallFlags flags,
+				  FuFirmwareParseFlags flags,
 				  GError **error)
 {
 	g_autoptr(FuFirmware) img = fu_efi_volume_new();
 	if (!fu_firmware_parse_stream(img,
 				      stream,
 				      0x0,
-				      flags | FWUPD_INSTALL_FLAG_NO_SEARCH,
+				      flags | FU_FIRMWARE_PARSE_FLAG_NO_SEARCH,
 				      error)) {
 		return FALSE;
 	}
@@ -78,7 +76,7 @@ fu_efi_section_parse_volume_image(FuEfiSection *self,
 static gboolean
 fu_efi_section_parse_lzma_sections(FuEfiSection *self,
 				   GInputStream *stream,
-				   FwupdInstallFlags flags,
+				   FuFirmwareParseFlags flags,
 				   GError **error)
 {
 	g_autoptr(GBytes) blob = NULL;
@@ -89,14 +87,14 @@ fu_efi_section_parse_lzma_sections(FuEfiSection *self,
 	blob = fu_input_stream_read_bytes(stream, 0, G_MAXSIZE, NULL, error);
 	if (blob == NULL)
 		return FALSE;
-	blob_uncomp = fu_lzma_decompress_bytes(blob, error);
+	blob_uncomp = fu_lzma_decompress_bytes(blob, 128 * 1024 * 1024, error);
 	if (blob_uncomp == NULL) {
-		g_prefix_error(error, "failed to decompress: ");
+		g_prefix_error_literal(error, "failed to decompress: ");
 		return FALSE;
 	}
 	stream_uncomp = g_memory_input_stream_new_from_bytes(blob_uncomp);
 	if (!fu_efi_parse_sections(FU_FIRMWARE(self), stream_uncomp, 0, flags, error)) {
-		g_prefix_error(error, "failed to parse sections: ");
+		g_prefix_error_literal(error, "failed to parse sections: ");
 		return FALSE;
 	}
 	return TRUE;
@@ -105,7 +103,7 @@ fu_efi_section_parse_lzma_sections(FuEfiSection *self,
 static gboolean
 fu_efi_section_parse_user_interface(FuEfiSection *self,
 				    GInputStream *stream,
-				    FwupdInstallFlags flags,
+				    FuFirmwareParseFlags flags,
 				    GError **error)
 {
 	FuEfiSectionPrivate *priv = GET_PRIVATE(self);
@@ -131,7 +129,7 @@ fu_efi_section_parse_user_interface(FuEfiSection *self,
 static gboolean
 fu_efi_section_parse_version(FuEfiSection *self,
 			     GInputStream *stream,
-			     FwupdInstallFlags flags,
+			     FuFirmwareParseFlags flags,
 			     GError **error)
 {
 	guint16 version_raw = 0;
@@ -139,18 +137,18 @@ fu_efi_section_parse_version(FuEfiSection *self,
 	g_autoptr(GByteArray) buf = NULL;
 
 	if (!fu_input_stream_read_u16(stream, 0x0, &version_raw, G_LITTLE_ENDIAN, error)) {
-		g_prefix_error(error, "failed to read raw version: ");
+		g_prefix_error_literal(error, "failed to read raw version: ");
 		return FALSE;
 	}
 	fu_firmware_set_version_raw(FU_FIRMWARE(self), version_raw);
 	buf = fu_input_stream_read_byte_array(stream, sizeof(guint16), G_MAXSIZE, NULL, error);
 	if (buf == NULL) {
-		g_prefix_error(error, "failed to read version buffer: ");
+		g_prefix_error_literal(error, "failed to read version buffer: ");
 		return FALSE;
 	}
 	version = fu_utf16_to_utf8_byte_array(buf, G_LITTLE_ENDIAN, error);
 	if (version == NULL) {
-		g_prefix_error(error, "failed to convert to UTF-16: ");
+		g_prefix_error_literal(error, "failed to convert to UTF-16: ");
 		return FALSE;
 	}
 	fu_firmware_set_version(FU_FIRMWARE(self), version); /* nocheck:set-version */
@@ -160,7 +158,7 @@ fu_efi_section_parse_version(FuEfiSection *self,
 static gboolean
 fu_efi_section_parse_compression_sections(FuEfiSection *self,
 					  GInputStream *stream,
-					  FwupdInstallFlags flags,
+					  FuFirmwareParseFlags flags,
 					  GError **error)
 {
 	g_autoptr(GByteArray) st = NULL;
@@ -170,7 +168,7 @@ fu_efi_section_parse_compression_sections(FuEfiSection *self,
 	if (fu_struct_efi_section_compression_get_compression_type(st) ==
 	    FU_EFI_COMPRESSION_TYPE_NOT_COMPRESSED) {
 		if (!fu_efi_parse_sections(FU_FIRMWARE(self), stream, st->len, flags, error)) {
-			g_prefix_error(error, "failed to parse sections: ");
+			g_prefix_error_literal(error, "failed to parse sections: ");
 			return FALSE;
 		}
 	} else {
@@ -182,7 +180,7 @@ fu_efi_section_parse_compression_sections(FuEfiSection *self,
 		if (lz77_stream == NULL)
 			return FALSE;
 		if (!fu_efi_parse_sections(FU_FIRMWARE(self), lz77_stream, 0, flags, error)) {
-			g_prefix_error(error, "failed to parse sections: ");
+			g_prefix_error_literal(error, "failed to parse sections: ");
 			return FALSE;
 		}
 	}
@@ -222,7 +220,7 @@ fu_efi_section_freeform_subtype_guid_to_string(const gchar *guid)
 static gboolean
 fu_efi_section_parse_freeform_subtype_guid(FuEfiSection *self,
 					   GInputStream *stream,
-					   FwupdInstallFlags flags,
+					   FuFirmwareParseFlags flags,
 					   GError **error)
 {
 	const gchar *guid_ui;
@@ -248,7 +246,7 @@ fu_efi_section_parse_freeform_subtype_guid(FuEfiSection *self,
 static gboolean
 fu_efi_section_parse(FuFirmware *firmware,
 		     GInputStream *stream,
-		     FwupdInstallFlags flags,
+		     FuFirmwareParseFlags flags,
 		     GError **error)
 {
 	FuEfiSection *self = FU_EFI_SECTION(firmware);
@@ -321,8 +319,10 @@ fu_efi_section_parse(FuFirmware *firmware,
 	/* create blob */
 	offset += st->len;
 	partial_stream = fu_partial_input_stream_new(stream, offset, size - offset, error);
-	if (partial_stream == NULL)
+	if (partial_stream == NULL) {
+		g_prefix_error_literal(error, "failed to cut data: ");
 		return FALSE;
+	}
 	fu_firmware_set_offset(firmware, offset);
 	fu_firmware_set_size(firmware, size);
 	if (!fu_firmware_set_stream(firmware, partial_stream, error))
@@ -331,14 +331,14 @@ fu_efi_section_parse(FuFirmware *firmware,
 	/* nested volume */
 	if (priv->type == FU_EFI_SECTION_TYPE_VOLUME_IMAGE) {
 		if (!fu_efi_section_parse_volume_image(self, partial_stream, flags, error)) {
-			g_prefix_error(error, "failed to parse nested volume: ");
+			g_prefix_error_literal(error, "failed to parse nested volume: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_GUID_DEFINED &&
 		   g_strcmp0(fu_firmware_get_id(firmware), FU_EFI_SECTION_GUID_LZMA_COMPRESS) ==
 		       0) {
 		if (!fu_efi_section_parse_lzma_sections(self, partial_stream, flags, error)) {
-			g_prefix_error(error, "failed to parse lzma section: ");
+			g_prefix_error_literal(error, "failed to parse lzma section: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_GUID_DEFINED &&
@@ -352,12 +352,12 @@ fu_efi_section_parse(FuFirmware *firmware,
 			  fu_firmware_get_id(firmware));
 	} else if (priv->type == FU_EFI_SECTION_TYPE_USER_INTERFACE) {
 		if (!fu_efi_section_parse_user_interface(self, partial_stream, flags, error)) {
-			g_prefix_error(error, "failed to parse user interface: ");
+			g_prefix_error_literal(error, "failed to parse user interface: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_VERSION) {
 		if (!fu_efi_section_parse_version(self, partial_stream, flags, error)) {
-			g_prefix_error(error, "failed to parse version: ");
+			g_prefix_error_literal(error, "failed to parse version: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_COMPRESSION) {
@@ -365,7 +365,7 @@ fu_efi_section_parse(FuFirmware *firmware,
 							       partial_stream,
 							       flags,
 							       error)) {
-			g_prefix_error(error, "failed to parse compression: ");
+			g_prefix_error_literal(error, "failed to parse compression: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_FREEFORM_SUBTYPE_GUID) {
@@ -373,7 +373,7 @@ fu_efi_section_parse(FuFirmware *firmware,
 								partial_stream,
 								flags,
 								error)) {
-			g_prefix_error(error, "failed to parse compression: ");
+			g_prefix_error_literal(error, "failed to parse compression: ");
 			return FALSE;
 		}
 	} else if (priv->type == FU_EFI_SECTION_TYPE_PEI_DEPEX ||
