@@ -58,9 +58,8 @@ fu_efi_x509_device_probe(FuDevice *device, GError **error)
 				     subject_vendor != NULL ? subject_vendor : "UNKNOWN");
 	fu_device_set_logical_id(device, logical_id);
 
-	fu_device_build_vendor_id(device,
-				  "UEFI",
-				  subject_vendor != NULL ? subject_vendor : "UNKNOWN");
+	if (subject_vendor != NULL)
+		fu_device_build_vendor_id(device, "UEFI", subject_vendor);
 
 	/* success */
 	fu_device_add_instance_strup(device, "CRT", fu_firmware_get_id(FU_FIRMWARE(priv->sig)));
@@ -116,10 +115,10 @@ fu_efi_x509_device_write_firmware(FuDevice *device,
 	/* process by the parent */
 	proxy = fu_device_get_proxy(device);
 	if (proxy == NULL) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "no proxy device assigned");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "no proxy device assigned");
 		return FALSE;
 	}
 	device_class = FU_DEVICE_GET_CLASS(proxy);
