@@ -19,10 +19,8 @@
 #include <string.h>
 
 #include "fu-byte-array.h"
-#include "fu-bytes.h"
 #include "fu-common.h"
 #include "fu-input-stream.h"
-#include "fu-mem-private.h"
 #include "fu-usb-endpoint-private.h"
 #include "fu-usb-interface-private.h"
 
