@@ -7,6 +7,7 @@
 #include "config.h"
 
 #include <scsi/sg.h>
+#include <stddef.h>
 
 #include "fu-ata-device.h"
 
@@ -144,7 +145,6 @@ fu_ata_device_parse_id_maybe_dell(FuAtaDevice *self, const guint16 *buf)
 	g_autofree gchar *component_id = NULL;
 	g_autofree gchar *guid_efi = NULL;
 	g_autofree gchar *guid_id = NULL;
-	g_autofree gchar *guid = NULL;
 
 	/* add extra component ID if set */
 	component_id = fu_ata_device_get_string(buf, 137, 140);
@@ -160,13 +160,11 @@ fu_ata_device_parse_id_maybe_dell(FuAtaDevice *self, const guint16 *buf)
 	/* add instance ID *and* GUID as using no-auto-instance-ids */
 	guid_id = g_strdup_printf("STORAGE-DELL-%s", component_id);
 	fu_device_add_instance_id(FU_DEVICE(self), guid_id);
-	guid = fwupd_guid_hash_string(guid_id);
-	fu_device_add_guid(FU_DEVICE(self), guid);
 
 	/* also add the EFI GUID */
 	guid_efi = fu_ata_device_get_guid_safe(buf, 129);
 	if (guid_efi != NULL)
-		fu_device_add_guid(FU_DEVICE(self), guid_efi);
+		fu_device_add_instance_id(FU_DEVICE(self), guid_efi);
 
 	/* owned by Dell */
 	fu_device_set_vendor(FU_DEVICE(self), "Dell");
@@ -331,7 +329,7 @@ fu_ata_device_parse_id(FuAtaDevice *self, const guint8 *buf, gsize sz, GError **
 	gboolean has_oui_quirk = FALSE;
 	guint16 xfer_min = 1;
 	guint16 xfer_max = 0xffff;
-	guint16 id[FU_ATA_IDENTIFY_SIZE / 2];
+	guint16 id[FU_ATA_IDENTIFY_SIZE / 2] = {0};
 	g_autofree gchar *name = NULL;
 	g_autofree gchar *sku = NULL;
 
@@ -657,7 +655,7 @@ fu_ata_device_setup(FuDevice *device, GError **error)
 	tf.command = ATA_OP_IDENTIFY;
 	tf.nsect = 1; /* 512 bytes */
 	if (!fu_ata_device_command(self, &tf, SG_DXFER_FROM_DEV, 1000, id, sizeof(id), error)) {
-		g_prefix_error(error, "failed to IDENTIFY: ");
+		g_prefix_error_literal(error, "failed to IDENTIFY: ");
 		return FALSE;
 	}
 	fu_dump_raw(G_LOG_DOMAIN, "IDENTIFY", id, sizeof(id));
@@ -684,7 +682,7 @@ fu_ata_device_activate(FuDevice *device, FuProgress *progress, GError **error)
 				   NULL,
 				   0,
 				   error)) {
-		g_prefix_error(error, "failed to flush cache immediate: ");
+		g_prefix_error_literal(error, "failed to flush cache immediate: ");
 		return FALSE;
 	}
 	tf.command = ATA_OP_STANDBY_IMMEDIATE;
@@ -695,7 +693,7 @@ fu_ata_device_activate(FuDevice *device, FuProgress *progress, GError **error)
 				   NULL,
 				   0,
 				   error)) {
-		g_prefix_error(error, "failed to standby immediate: ");
+		g_prefix_error_literal(error, "failed to standby immediate: ");
 		return FALSE;
 	}
 
@@ -710,7 +708,7 @@ fu_ata_device_activate(FuDevice *device, FuProgress *progress, GError **error)
 				   NULL,
 				   0,
 				   error)) {
-		g_prefix_error(error, "failed to activate firmware: ");
+		g_prefix_error_literal(error, "failed to activate firmware: ");
 		return FALSE;
 	}
 
@@ -893,6 +891,7 @@ fu_ata_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
@@ -912,7 +911,7 @@ fu_ata_device_init(FuAtaDevice *self)
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_MD_SET_SIGNED);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_MD_SET_FLAGS);
 	fu_device_set_summary(FU_DEVICE(self), "ATA drive");
-	fu_device_add_icon(FU_DEVICE(self), "drive-harddisk");
+	fu_device_add_icon(FU_DEVICE(self), FU_DEVICE_ICON_DRIVE_HARDDISK);
 	fu_device_add_protocol(FU_DEVICE(self), "org.t13.ata");
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PLAIN);
 	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_READ);
