@@ -35,7 +35,7 @@ fu_aver_safeisp_device_transfer(FuAverSafeispDevice *self,
 					      FU_AVER_SAFEISP_DEVICE_TIMEOUT,
 					      FU_HID_DEVICE_FLAG_USE_INTERRUPT_TRANSFER,
 					      error)) {
-			g_prefix_error(error, "failed to send packet: ");
+			g_prefix_error_literal(error, "failed to send packet: ");
 			return FALSE;
 		}
 	}
@@ -47,7 +47,7 @@ fu_aver_safeisp_device_transfer(FuAverSafeispDevice *self,
 					      FU_AVER_SAFEISP_DEVICE_TIMEOUT,
 					      FU_HID_DEVICE_FLAG_USE_INTERRUPT_TRANSFER,
 					      error)) {
-			g_prefix_error(error, "failed to receive packet: ");
+			g_prefix_error_literal(error, "failed to receive packet: ");
 			return FALSE;
 		}
 		g_debug("custom-isp-cmd: %s [0x%x]",
@@ -396,6 +396,7 @@ static void
 fu_aver_safeisp_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 68, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 31, "attach");
@@ -412,7 +413,6 @@ fu_aver_safeisp_device_init(FuAverSafeispDevice *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_DUAL_IMAGE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SELF_RECOVERY);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
-	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_ONLY_WAIT_FOR_REPLUG);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_AUTO_PAUSE_POLLING);
 	fu_device_set_remove_delay(FU_DEVICE(self), 150000);
 	fu_hid_device_add_flag(FU_HID_DEVICE(self), FU_HID_DEVICE_FLAG_RETRY_FAILURE);
