@@ -122,7 +122,7 @@ fu_corsair_device_poll_subdevice(FuDevice *device, gboolean *subdevice_added, GE
 					FU_CORSAIR_BP_PROPERTY_SUBDEVICES,
 					&subdevices,
 					error)) {
-		g_prefix_error(error, "cannot get subdevices: ");
+		g_prefix_error_literal(error, "cannot get subdevices: ");
 		return FALSE;
 	}
 
@@ -214,14 +214,14 @@ fu_corsair_device_setup(FuDevice *device, GError **error)
 
 	version = fu_corsair_device_get_version(device, error);
 	if (version == NULL) {
-		g_prefix_error(error, "cannot get version: ");
+		g_prefix_error_literal(error, "cannot get version: ");
 		return FALSE;
 	}
 	fu_device_set_version(device, version);
 
 	bootloader_version = fu_corsair_device_get_bootloader_version(self->bp, error);
 	if (bootloader_version == NULL) {
-		g_prefix_error(error, "cannot get bootloader version: ");
+		g_prefix_error_literal(error, "cannot get bootloader version: ");
 		return FALSE;
 	}
 	fu_device_set_version_bootloader(device, bootloader_version);
@@ -232,7 +232,7 @@ fu_corsair_device_setup(FuDevice *device, GError **error)
 						FU_CORSAIR_BP_PROPERTY_BATTERY_LEVEL,
 						&battery_level,
 						error)) {
-			g_prefix_error(error, "cannot get battery level: ");
+			g_prefix_error_literal(error, "cannot get battery level: ");
 			return FALSE;
 		}
 		fu_device_set_battery_level(device, battery_level / 10);
@@ -286,12 +286,15 @@ fu_corsair_device_is_subdevice_connected_cb(FuDevice *device, gpointer user_data
 					FU_CORSAIR_BP_PROPERTY_SUBDEVICES,
 					&subdevices,
 					error)) {
-		g_prefix_error(error, "cannot get subdevices: ");
+		g_prefix_error_literal(error, "cannot get subdevices: ");
 		return FALSE;
 	}
 
 	if (subdevices == 0) {
-		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "subdevice is not connected");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INTERNAL,
+				    "subdevice is not connected");
 		return FALSE;
 	}
 	return TRUE;
@@ -303,7 +306,10 @@ fu_corsair_device_reconnect_subdevice(FuDevice *device, GError **error)
 	FuDevice *parent = fu_device_get_parent(device);
 
 	if (parent == NULL) {
-		g_prefix_error(error, "cannot get parent: ");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INTERNAL,
+				    "cannot get parent: ");
 		return FALSE;
 	}
 
@@ -316,7 +322,7 @@ fu_corsair_device_reconnect_subdevice(FuDevice *device, GError **error)
 				  CORSAIR_SUBDEVICE_RECONNECT_PERIOD,
 				  NULL,
 				  error)) {
-		g_prefix_error(error, "a subdevice did not reconnect after attach: ");
+		g_prefix_error_literal(error, "a subdevice did not reconnect after attach: ");
 		return FALSE;
 	}
 
@@ -340,19 +346,19 @@ fu_corsair_device_ensure_mode(FuDevice *device, FuCorsairDeviceMode mode, GError
 
 	if (mode == FU_CORSAIR_DEVICE_MODE_APPLICATION) {
 		if (!fu_device_attach(FU_DEVICE(self->bp), error)) {
-			g_prefix_error(error, "attach failed: ");
+			g_prefix_error_literal(error, "attach failed: ");
 			return FALSE;
 		}
 	} else {
 		if (!fu_device_detach(FU_DEVICE(self->bp), error)) {
-			g_prefix_error(error, "detach failed: ");
+			g_prefix_error_literal(error, "detach failed: ");
 			return FALSE;
 		}
 	}
 
 	if (fu_device_has_private_flag(device, FU_CORSAIR_DEVICE_FLAG_IS_SUBDEVICE)) {
 		if (!fu_corsair_device_reconnect_subdevice(device, error)) {
-			g_prefix_error(error, "subdevice did not reconnect: ");
+			g_prefix_error_literal(error, "subdevice did not reconnect: ");
 			return FALSE;
 		}
 		if (mode == FU_CORSAIR_DEVICE_MODE_BOOTLOADER) {
@@ -387,23 +393,17 @@ fu_corsair_device_write_firmware(FuDevice *device,
 				 GError **error)
 {
 	FuCorsairDevice *self = FU_CORSAIR_DEVICE(device);
-	g_autoptr(GInputStream) stream = fu_firmware_get_stream(firmware, error);
-
-	if (stream == NULL) {
-		g_prefix_error(error, "cannot get firmware stream: ");
-		return FALSE;
-	}
 
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 95, NULL);
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 5, NULL);
 
 	if (!fu_device_write_firmware(FU_DEVICE(self->bp),
-				      stream,
+				      firmware,
 				      fu_progress_get_child(progress),
 				      flags,
 				      error)) {
-		g_prefix_error(error, "cannot write firmware: ");
+		g_prefix_error_literal(error, "cannot write firmware: ");
 		return FALSE;
 	}
 
@@ -411,7 +411,7 @@ fu_corsair_device_write_firmware(FuDevice *device,
 
 	if (!fu_device_has_private_flag(device, FU_CORSAIR_DEVICE_FLAG_LEGACY_ATTACH)) {
 		if (!fu_corsair_bp_activate_firmware(self->bp, firmware, error)) {
-			g_prefix_error(error, "firmware activation fail: ");
+			g_prefix_error_literal(error, "firmware activation fail: ");
 			return FALSE;
 		}
 		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
@@ -438,6 +438,7 @@ static void
 fu_corsair_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 4, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 92, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 4, "attach");
@@ -472,7 +473,7 @@ fu_corsair_device_set_quirk_kv(FuDevice *device,
 				 G_MAXUINT8,
 				 FU_INTEGER_BASE_AUTO,
 				 error)) {
-			g_prefix_error(error, "cannot parse CorsairVendorInterface: ");
+			g_prefix_error_literal(error, "cannot parse CorsairVendorInterface: ");
 			return FALSE;
 		}
 		self->vendor_interface = vendor_interface;
@@ -498,7 +499,7 @@ fu_corsair_device_poll(FuDevice *device, GError **error)
 
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL) {
-		g_prefix_error(error, "cannot open device: ");
+		g_prefix_error_literal(error, "cannot open device: ");
 		return FALSE;
 	}
 
@@ -508,10 +509,10 @@ fu_corsair_device_poll(FuDevice *device, GError **error)
 
 	/* stop polling if a subdevice was added */
 	if (subdevice_added) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOTHING_TO_DO,
-			    "subdevice added successfully");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOTHING_TO_DO,
+				    "subdevice added successfully");
 		return FALSE;
 	}
 
