@@ -54,7 +54,7 @@ static FuFirmware *
 fu_fpc_device_prepare_firmware(FuDevice *device,
 			       GInputStream *stream,
 			       FuProgress *progress,
-			       FwupdInstallFlags flags,
+			       FuFirmwareParseFlags flags,
 			       GError **error)
 {
 	return fu_firmware_new_from_gtypes(stream,
@@ -92,7 +92,7 @@ fu_fpc_device_dfu_cmd(FuFpcDevice *self,
 		FPC_USB_TRANSFER_TIMEOUT,
 		NULL,
 		error)) {
-		fu_error_convert(error);
+		fwupd_error_convert(error);
 		return FALSE;
 	}
 	if (actual_len != length) {
@@ -131,7 +131,7 @@ fu_fpc_device_fw_cmd(FuFpcDevice *self,
 					    FPC_USB_TRANSFER_TIMEOUT,
 					    NULL,
 					    error)) {
-		fu_error_convert(error);
+		fwupd_error_convert(error);
 		return FALSE;
 	}
 	if (actual_len != length) {
@@ -209,7 +209,8 @@ fu_fpc_device_setup_version(FuFpcDevice *self, GError **error)
 						   FALSE,
 						   FALSE,
 						   error)) {
-				g_prefix_error(error, "fail to clear status in setup version");
+				g_prefix_error_literal(error,
+						       "fail to clear status in setup version");
 				return FALSE;
 			}
 		}
@@ -223,7 +224,7 @@ fu_fpc_device_setup_version(FuFpcDevice *self, GError **error)
 					   TRUE,
 					   TRUE,
 					   error)) {
-			g_prefix_error(error, "fail to get fw status in setup version");
+			g_prefix_error_literal(error, "fail to get fw status in setup version");
 			return FALSE;
 		}
 
@@ -255,7 +256,7 @@ fu_fpc_device_check_dfu_status_cb(FuDevice *device, gpointer user_data, GError *
 				   TRUE,
 				   FALSE,
 				   error)) {
-		g_prefix_error(error, "failed to get status: ");
+		g_prefix_error_literal(error, "failed to get status: ");
 		return FALSE;
 	}
 
@@ -292,7 +293,7 @@ fu_fpc_device_update_init(FuFpcDevice *self, GError **error)
 					   FALSE,
 					   FALSE,
 					   error)) {
-			g_prefix_error(error, "failed to clear status: ");
+			g_prefix_error_literal(error, "failed to clear status: ");
 			return FALSE;
 		}
 	}
@@ -381,13 +382,13 @@ fu_fpc_device_setup(FuDevice *device, GError **error)
 	}
 
 	if (!fu_fpc_device_setup_mode(self, error)) {
-		g_prefix_error(error, "failed to get device mode: ");
+		g_prefix_error_literal(error, "failed to get device mode: ");
 		return FALSE;
 	}
 
 	/* ensure version */
 	if (!fu_fpc_device_setup_version(self, error)) {
-		g_prefix_error(error, "failed to get firmware version: ");
+		g_prefix_error_literal(error, "failed to get firmware version: ");
 		return FALSE;
 	}
 
@@ -400,7 +401,11 @@ fu_fpc_device_write_ff2_blocks(FuFpcDevice *self, GInputStream *stream, GError *
 {
 	g_autoptr(FuChunkArray) chunks = NULL;
 
-	chunks = fu_chunk_array_new_from_stream(stream, 0x0, FPC_FLASH_BLOCK_SIZE_4096, error);
+	chunks = fu_chunk_array_new_from_stream(stream,
+						FU_CHUNK_ADDR_OFFSET_NONE,
+						FU_CHUNK_PAGESZ_NONE,
+						FPC_FLASH_BLOCK_SIZE_4096,
+						error);
 	if (chunks == NULL)
 		return FALSE;
 	for (guint i = 0; i < fu_chunk_array_length(chunks); i++) {
@@ -475,6 +480,7 @@ fu_fpc_device_write_ff2_firmware(FuFpcDevice *self,
 			buf_sec = fu_input_stream_read_byte_array(stream,
 								  offset,
 								  FPC_FF2_BLK_SEC_LINK_LEN,
+								  fu_progress_get_child(progress),
 								  error);
 			if (buf_sec == NULL)
 				return FALSE;
@@ -486,7 +492,7 @@ fu_fpc_device_write_ff2_firmware(FuFpcDevice *self,
 						   FALSE,
 						   FALSE,
 						   error)) {
-				g_prefix_error(error, "failed to write sec-link: ");
+				g_prefix_error_literal(error, "failed to write sec-link: ");
 				return FALSE;
 			}
 
@@ -569,7 +575,11 @@ fu_fpc_device_write_firmware(FuDevice *device,
 	fu_progress_step_done(progress);
 
 	/* build packets */
-	chunks = fu_chunk_array_new_from_stream(stream, 0x00, self->max_block_size, error);
+	chunks = fu_chunk_array_new_from_stream(stream,
+						FU_CHUNK_ADDR_OFFSET_NONE,
+						FU_CHUNK_PAGESZ_NONE,
+						self->max_block_size,
+						error);
 	if (chunks == NULL)
 		return FALSE;
 
@@ -630,7 +640,7 @@ fu_fpc_device_write_firmware(FuDevice *device,
 					   FALSE,
 					   FALSE,
 					   error)) {
-			g_prefix_error(error, "fail to exit dnload loop: ");
+			g_prefix_error_literal(error, "fail to exit dnload loop: ");
 			return FALSE;
 		}
 	}
@@ -654,6 +664,7 @@ static void
 fu_fpc_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
