@@ -35,7 +35,7 @@ fu_steelseries_fizz_tunnel_ping(FuDevice *device, gboolean *reached, GError **er
 	if (!fu_steelseries_fizz_impl_get_connection_status(FU_STEELSERIES_FIZZ_IMPL(proxy),
 							    &status,
 							    error)) {
-		g_prefix_error(error, "failed to get connection status: ");
+		g_prefix_error_literal(error, "failed to get connection status: ");
 		return FALSE;
 	}
 	g_debug("FuSteelseriesFizzConnection: %s",
@@ -93,19 +93,22 @@ fu_steelseries_fizz_tunnel_wait_for_reconnect_cb(FuDevice *device,
 	if (!fu_steelseries_fizz_get_connection_status(FU_STEELSERIES_FIZZ(parent),
 						       &status,
 						       error)) {
-		g_prefix_error(error, "failed to get connection status: ");
+		g_prefix_error_literal(error, "failed to get connection status: ");
 		return FALSE;
 	}
 	g_debug("FuSteelseriesFizzConnection: %s",
 		fu_steelseries_fizz_connection_status_to_string(status));
 	if (status == FU_STEELSERIES_FIZZ_CONNECTION_STATUS_NOT_CONNECTED) {
-		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND, "device is unreachable");
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_FOUND,
+				    "device is unreachable");
 		return FALSE;
 	}
 
 	/* ping */
 	if (!fu_steelseries_fizz_tunnel_ping(device, &reached, error)) {
-		g_prefix_error(error, "failed to ping on reconnect: ");
+		g_prefix_error_literal(error, "failed to ping on reconnect: ");
 		return FALSE;
 	}
 
@@ -169,7 +172,7 @@ fu_steelseries_fizz_tunnel_attach(FuDevice *device, FuProgress *progress, GError
 				       TRUE,
 				       FU_STEELSERIES_FIZZ_RESET_MODE_NORMAL,
 				       &error_local))
-		g_warning("failed to reset: %s", error_local->message);
+		g_debug("failed to reset: %s", error_local->message);
 	fu_progress_step_done(progress);
 
 	/* wait for receiver to reset the connection status to 0 */
@@ -258,7 +261,7 @@ fu_steelseries_fizz_tunnel_setup(FuDevice *device, GError **error)
 	}
 
 	serial = fu_steelseries_fizz_impl_get_serial(FU_STEELSERIES_FIZZ_IMPL(proxy),
-						     FALSE,
+						     TRUE,
 						     &error_local);
 	if (serial != NULL) {
 		fu_device_set_serial(device, serial);
@@ -304,7 +307,7 @@ fu_steelseries_fizz_tunnel_poll(FuDevice *device, GError **error)
 		return FALSE;
 
 	if (!fu_steelseries_fizz_tunnel_ping(device, &reached, error)) {
-		g_prefix_error(error, "failed to ping: ");
+		g_prefix_error_literal(error, "failed to ping: ");
 		return FALSE;
 	}
 
@@ -421,6 +424,7 @@ static void
 fu_steelseries_fizz_tunnel_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 6, "attach");
@@ -458,7 +462,6 @@ fu_steelseries_fizz_tunnel_init(FuSteelseriesFizzTunnel *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_STEELSERIES_DEVICE_FLAG_DETACH_BOOTLOADER);
-	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_ONLY_WAIT_FOR_REPLUG);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_USE_PROXY_FOR_OPEN);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_REFCOUNTED_PROXY);
 	fu_device_add_private_flag(FU_DEVICE(self), FU_DEVICE_PRIVATE_FLAG_AUTO_PAUSE_POLLING);
