@@ -41,6 +41,8 @@ G_DEFINE_TYPE(FuSynapticsRmiHidDevice, fu_synaptics_rmi_hid_device, FU_TYPE_SYNA
 #define HID_RMI4_ATTN_INTERRUPT_SOURCES 1
 #define HID_RMI4_ATTN_DATA		2
 
+#define HID_RMI4_REPORT_ID_SIZE	  1 /* Size of the report ID field */
+#define HID_RMI4_DATA_LENGTH_SIZE 1 /* Size of the data length field */
 /*
  * This bit disables whatever sleep mode may be selected by the sleep_mode
  * field and forces the device to run at full power without sleeping.
@@ -105,7 +107,8 @@ fu_synaptics_rmi_hid_device_read(FuSynapticsRmiDevice *rmi_device,
 		guint8 input_count_sz = 0;
 		g_autoptr(GByteArray) res = NULL;
 		res = fu_io_channel_read_byte_array(io_channel,
-						    req_sz,
+						    req_sz + HID_RMI4_REPORT_ID_SIZE +
+							HID_RMI4_DATA_LENGTH_SIZE,
 						    RMI_DEVICE_DEFAULT_TIMEOUT,
 						    FU_IO_CHANNEL_FLAG_SINGLE_SHOT,
 						    error);
@@ -478,7 +481,7 @@ fu_synaptics_rmi_hid_device_disable_sleep(FuSynapticsRmiDevice *rmi_device, GErr
 		return FALSE;
 	f01_control0 = fu_synaptics_rmi_device_read(rmi_device, f01->control_base, 0x1, error);
 	if (f01_control0 == NULL) {
-		g_prefix_error(error, "failed to write get f01_control0: ");
+		g_prefix_error_literal(error, "failed to write get f01_control0: ");
 		return FALSE;
 	}
 	f01_control0->data[0] |= RMI_F01_CRTL0_NOSLEEP_BIT;
@@ -489,7 +492,7 @@ fu_synaptics_rmi_hid_device_disable_sleep(FuSynapticsRmiDevice *rmi_device, GErr
 					   f01_control0,
 					   FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
 					   error)) {
-		g_prefix_error(error, "failed to write f01_control0: ");
+		g_prefix_error_literal(error, "failed to write f01_control0: ");
 		return FALSE;
 	}
 
@@ -522,6 +525,7 @@ static void
 fu_synaptics_rmi_hid_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 0, "prepare-fw");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 3, "detach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 88, "write");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 7, "attach");
@@ -534,6 +538,8 @@ fu_synaptics_rmi_hid_device_init(FuSynapticsRmiHidDevice *self)
 	fu_device_set_name(FU_DEVICE(self), "Touchpad");
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_synaptics_rmi_device_set_max_page(FU_SYNAPTICS_RMI_DEVICE(self), 0xff);
+	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_READ);
+	fu_udev_device_add_open_flag(FU_UDEV_DEVICE(self), FU_IO_CHANNEL_OPEN_FLAG_WRITE);
 }
 
 static void
