@@ -12,7 +12,6 @@
 
 #include "fu-device-list.h"
 #include "fu-device-private.h"
-#include "fu-engine.h"
 
 /**
  * FuDeviceList:
@@ -40,6 +39,13 @@ enum { SIGNAL_ADDED, SIGNAL_REMOVED, SIGNAL_CHANGED, SIGNAL_LAST };
 
 static guint signals[SIGNAL_LAST] = {0};
 
+enum {
+	QUARK_UNCONNECTED,
+	QUARK_LAST,
+};
+
+static guint quarks[QUARK_LAST] = {0};
+
 typedef struct {
 	FuDevice *device;
 	FuDevice *device_old;
@@ -223,7 +229,7 @@ fu_device_list_get_active(FuDeviceList *self)
 	g_rw_lock_reader_lock(&self->devices_mutex);
 	for (guint i = 0; i < self->devices->len; i++) {
 		FuDeviceItem *item = g_ptr_array_index(self->devices, i);
-		if (fu_device_has_private_flag(item->device, FU_DEVICE_PRIVATE_FLAG_UNCONNECTED))
+		if (fu_device_has_private_flag_quark(item->device, quarks[QUARK_UNCONNECTED]))
 			continue;
 		if (fu_device_has_inhibit(item->device, "hidden"))
 			continue;
@@ -322,6 +328,14 @@ fu_device_list_filter_by_id(FuDeviceList *self, const gchar *device_id, GError *
 
 	/* support abbreviated hashes */
 	device_id_len = strlen(device_id);
+	if (device_id_len < 4) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_INTERNAL,
+			    "invalid device ID: %s",
+			    device_id);
+		return NULL;
+	}
 	g_rw_lock_reader_lock(&self->devices_mutex);
 	for (guint i = 0; i < self->devices->len; i++) {
 		FuDeviceItem *item_tmp = g_ptr_array_index(self->devices, i);
@@ -433,7 +447,10 @@ fu_device_list_get_by_guids_removed(FuDeviceList *self, GPtrArray *guids)
 		for (guint j = 0; j < guids->len; j++) {
 			const gchar *guid = g_ptr_array_index(guids, j);
 			if (fu_device_has_guid(item->device, guid) ||
-			    fu_device_has_counterpart_guid(item->device, guid))
+			    fu_device_has_instance_id(item->device,
+						      guid,
+						      FU_DEVICE_INSTANCE_FLAG_COUNTERPART |
+							  FU_DEVICE_INSTANCE_FLAG_VISIBLE))
 				return item;
 		}
 	}
@@ -446,7 +463,10 @@ fu_device_list_get_by_guids_removed(FuDeviceList *self, GPtrArray *guids)
 		for (guint j = 0; j < guids->len; j++) {
 			const gchar *guid = g_ptr_array_index(guids, j);
 			if (fu_device_has_guid(item->device_old, guid) ||
-			    fu_device_has_counterpart_guid(item->device_old, guid))
+			    fu_device_has_instance_id(item->device_old,
+						      guid,
+						      FU_DEVICE_INSTANCE_FLAG_COUNTERPART |
+							  FU_DEVICE_INSTANCE_FLAG_VISIBLE))
 				return item;
 		}
 	}
@@ -508,7 +528,7 @@ fu_device_list_should_remove_with_delay(FuDevice *device)
 {
 	if (fu_device_get_remove_delay(device) == 0)
 		return FALSE;
-	if (fu_device_has_private_flag(device, FU_DEVICE_PRIVATE_FLAG_ONLY_WAIT_FOR_REPLUG) &&
+	if (!fu_device_has_private_flag(device, FU_DEVICE_PRIVATE_FLAG_DELAYED_REMOVAL) &&
 	    !fu_device_has_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG))
 		return FALSE;
 	return TRUE;
@@ -611,12 +631,16 @@ fu_device_list_add_missing_guids(FuDevice *device_new, FuDevice *device_old)
 	for (guint i = 0; i < guids_old->len; i++) {
 		const gchar *guid_tmp = g_ptr_array_index(guids_old, i);
 		if (!fu_device_has_guid(device_new, guid_tmp) &&
-		    !fu_device_has_counterpart_guid(device_new, guid_tmp)) {
+		    !fu_device_has_instance_id(device_new,
+					       guid_tmp,
+					       FU_DEVICE_INSTANCE_FLAG_COUNTERPART)) {
 			if (fu_device_has_private_flag(
 				device_new,
 				FU_DEVICE_PRIVATE_FLAG_ADD_COUNTERPART_GUIDS)) {
 				g_info("adding GUID %s to device", guid_tmp);
-				fu_device_add_counterpart_guid(device_new, guid_tmp);
+				fu_device_add_instance_id_full(device_new,
+							       guid_tmp,
+							       FU_DEVICE_INSTANCE_FLAG_COUNTERPART);
 			} else {
 				g_info("not adding GUID %s to device, use "
 				       "FU_DEVICE_PRIVATE_FLAG_ADD_COUNTERPART_GUIDS if required",
@@ -817,6 +841,9 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 	g_return_if_fail(FU_IS_DEVICE_LIST(self));
 	g_return_if_fail(FU_IS_DEVICE(device));
 
+	/* make tests easier */
+	fu_device_convert_instance_ids(device);
+
 	/* is the device waiting to be replugged? */
 	item = fu_device_list_find_by_id(self, fu_device_get_id(device), NULL);
 	if (item != NULL) {
@@ -883,8 +910,8 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 	/* verify a compatible device does not already exist */
 	item = fu_device_list_get_by_guids_removed(self, fu_device_get_guids(device));
 	if (item == NULL) {
-		item = fu_device_list_get_by_guids_removed(self,
-							   fu_device_get_counterpart_guids(device));
+		g_autoptr(GPtrArray) guids = fu_device_get_counterpart_guids(device);
+		item = fu_device_list_get_by_guids_removed(self, guids);
 	}
 	if (item != NULL) {
 		if (fu_device_has_private_flag(device, FU_DEVICE_PRIVATE_FLAG_REPLUG_MATCH_GUID)) {
@@ -1006,7 +1033,9 @@ fu_device_list_wait_for_replug(FuDeviceList *self, GError **error)
 	do {
 		g_autoptr(GPtrArray) devices_wfr_tmp = NULL;
 		g_usleep(1000);
-		g_main_context_iteration(NULL, FALSE);
+		while (g_main_context_iteration(NULL, FALSE)) {
+			/* nothing needs to be done here */
+		};
 		devices_wfr_tmp = fu_device_list_get_wait_for_replug(self);
 		if (devices_wfr_tmp->len == 0)
 			break;
@@ -1109,6 +1138,9 @@ fu_device_list_class_init(FuDeviceListClass *klass)
 	object_class->dispose = fu_device_list_dispose;
 	object_class->finalize = fu_device_list_finalize;
 
+	/* used as device flags */
+	quarks[QUARK_UNCONNECTED] = g_quark_from_static_string(FU_DEVICE_PRIVATE_FLAG_UNCONNECTED);
+
 	/**
 	 * FuDeviceList::added:
 	 * @self: the #FuDeviceList instance that emitted the signal
